@@ -1,6 +1,6 @@
 """NumPy-style histograms in PyTorch"""
 
-__version__ = '0.1.2'
+__version__ = '0.1.4'
 
 
 import torch
@@ -224,7 +224,7 @@ def histogramdd(
     shape = torch.Size(bins.expand(D))
 
     if sparse:
-        hist = torch.sparse_coo_tensor(idx.t(), weights, shape).coalesce()
+        hist = torch.sparse_coo_tensor(idx.t(), weights, shape)
     else:
         if D > 1:
             idx = ravel_multi_index(idx, shape)
@@ -364,13 +364,10 @@ def reduce_histogramdd(
         else:
             hist = hist + temp.to(hist)
 
-    if hist.is_sparse:
-        hist = hist.coalesce()
-
     return hist
 
 
-def normalize(hist: Tensor) -> Tensor:
+def normalize(hist: Tensor) -> Tuple[Tensor, Tensor]:
     r"""Normalizes a histogram, that is, the sum of its elements is equal to one.
 
     Args:
@@ -385,7 +382,7 @@ def normalize(hist: Tensor) -> Tensor:
     else:
         norm = hist.sum()
 
-    return hist / norm
+    return hist / norm, norm
 
 
 def marginalize(hist: Tensor, dim: Union[int, Shape], keep: bool = False) -> Tensor:
